==> zio-aws-servicecatalog_2.13-5.17.121.3-sources.jar: zio/aws/servicecatalog/model/UpdateProvisioningPreferences.scala <==
package zio.aws.servicecatalog.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.{
  StackSetMaxConcurrencyCount,
  AccountId,
  StackSetFailureToleranceCount,
  Region,
  StackSetFailureTolerancePercentage,
  StackSetMaxConcurrencyPercentage
}
import scala.jdk.CollectionConverters._
final case class UpdateProvisioningPreferences(
    stackSetAccounts: Option[Iterable[AccountId]] = None,
    stackSetRegions: Option[Iterable[Region]] = None,
    stackSetFailureToleranceCount: Option[StackSetFailureToleranceCount] = None,
    stackSetFailureTolerancePercentage: Option[
      StackSetFailureTolerancePercentage
    ] = None,
    stackSetMaxConcurrencyCount: Option[StackSetMaxConcurrencyCount] = None,
    stackSetMaxConcurrencyPercentage: Option[StackSetMaxConcurrencyPercentage] =
      None,
    stackSetOperationType: Option[
      zio.aws.servicecatalog.model.StackSetOperationType
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences = {
    import UpdateProvisioningPreferences.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
      .builder()
      .optionallyWith(
        stackSetAccounts.map(value =>
          value.map { item =>
            AccountId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.stackSetAccounts)
      .optionallyWith(
        stackSetRegions.map(value =>
          value.map { item =>
            Region.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.stackSetRegions)
      .optionallyWith(
        stackSetFailureToleranceCount.map(value =>
          StackSetFailureToleranceCount.unwrap(value): Integer
        )
      )(_.stackSetFailureToleranceCount)
      .optionallyWith(
        stackSetFailureTolerancePercentage.map(value =>
          StackSetFailureTolerancePercentage.unwrap(value): Integer
        )
      )(_.stackSetFailureTolerancePercentage)
      .optionallyWith(
        stackSetMaxConcurrencyCount.map(value =>
          StackSetMaxConcurrencyCount.unwrap(value): Integer
        )
      )(_.stackSetMaxConcurrencyCount)
      .optionallyWith(
        stackSetMaxConcurrencyPercentage.map(value =>
          StackSetMaxConcurrencyPercentage.unwrap(value): Integer
        )
      )(_.stackSetMaxConcurrencyPercentage)
      .optionallyWith(stackSetOperationType.map(value => value.unwrap))(
        _.stackSetOperationType
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.UpdateProvisioningPreferences.ReadOnly =
    zio.aws.servicecatalog.model.UpdateProvisioningPreferences
      .wrap(buildAwsValue())
}
object UpdateProvisioningPreferences {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.UpdateProvisioningPreferences =
      zio.aws.servicecatalog.model.UpdateProvisioningPreferences(
        stackSetAccounts.map(value => value),
        stackSetRegions.map(value => value),
        stackSetFailureToleranceCount.map(value => value),
        stackSetFailureTolerancePercentage.map(value => value),
        stackSetMaxConcurrencyCount.map(value => value),
        stackSetMaxConcurrencyPercentage.map(value => value),
        stackSetOperationType.map(value => value)
      )
    def stackSetAccounts: Option[List[AccountId]]
    def stackSetRegions: Option[List[Region]]
    def stackSetFailureToleranceCount: Option[StackSetFailureToleranceCount]
    def stackSetFailureTolerancePercentage
        : Option[StackSetFailureTolerancePercentage]
    def stackSetMaxConcurrencyCount: Option[StackSetMaxConcurrencyCount]
    def stackSetMaxConcurrencyPercentage
        : Option[StackSetMaxConcurrencyPercentage]
    def stackSetOperationType
        : Option[zio.aws.servicecatalog.model.StackSetOperationType]
    def getStackSetAccounts: ZIO[Any, AwsError, List[AccountId]] =
      AwsError.unwrapOptionField("stackSetAccounts", stackSetAccounts)
    def getStackSetRegions: ZIO[Any, AwsError, List[Region]] =
      AwsError.unwrapOptionField("stackSetRegions", stackSetRegions)
    def getStackSetFailureToleranceCount
        : ZIO[Any, AwsError, StackSetFailureToleranceCount] =
      AwsError.unwrapOptionField(
        "stackSetFailureToleranceCount",
        stackSetFailureToleranceCount
      )
    def getStackSetFailureTolerancePercentage
        : ZIO[Any, AwsError, StackSetFailureTolerancePercentage] =
      AwsError.unwrapOptionField(
        "stackSetFailureTolerancePercentage",
        stackSetFailureTolerancePercentage
      )
    def getStackSetMaxConcurrencyCount
        : ZIO[Any, AwsError, StackSetMaxConcurrencyCount] =
      AwsError.unwrapOptionField(
        "stackSetMaxConcurrencyCount",
        stackSetMaxConcurrencyCount
      )
    def getStackSetMaxConcurrencyPercentage
        : ZIO[Any, AwsError, StackSetMaxConcurrencyPercentage] =
      AwsError.unwrapOptionField(
        "stackSetMaxConcurrencyPercentage",
        stackSetMaxConcurrencyPercentage
      )
    def getStackSetOperationType: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.StackSetOperationType
    ] =
      AwsError.unwrapOptionField("stackSetOperationType", stackSetOperationType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
  ) extends zio.aws.servicecatalog.model.UpdateProvisioningPreferences.ReadOnly {
    override val stackSetAccounts: Option[List[AccountId]] = scala
      .Option(impl.stackSetAccounts())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.servicecatalog.model.primitives.AccountId(item)
        }.toList
      )
    override val stackSetRegions: Option[List[Region]] = scala
      .Option(impl.stackSetRegions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.servicecatalog.model.primitives.Region(item)
        }.toList
      )
    override val stackSetFailureToleranceCount
        : Option[StackSetFailureToleranceCount] = scala
      .Option(impl.stackSetFailureToleranceCount())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetFailureToleranceCount(value)
      )
    override val stackSetFailureTolerancePercentage
        : Option[StackSetFailureTolerancePercentage] = scala
      .Option(impl.stackSetFailureTolerancePercentage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetFailureTolerancePercentage(value)
      )
    override val stackSetMaxConcurrencyCount
        : Option[StackSetMaxConcurrencyCount] = scala
      .Option(impl.stackSetMaxConcurrencyCount())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetMaxConcurrencyCount(value)
      )
    override val stackSetMaxConcurrencyPercentage
        : Option[StackSetMaxConcurrencyPercentage] = scala
      .Option(impl.stackSetMaxConcurrencyPercentage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetMaxConcurrencyPercentage(value)
      )
    override val stackSetOperationType
        : Option[zio.aws.servicecatalog.model.StackSetOperationType] = scala
      .Option(impl.stackSetOperationType())
      .map(value =>
        zio.aws.servicecatalog.model.StackSetOperationType.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
  ): zio.aws.servicecatalog.model.UpdateProvisioningPreferences.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-6.20.103.2-sources.jar: zio/aws/servicecatalog/model/UpdateProvisioningPreferences.scala <==
package zio.aws.servicecatalog.model
import zio.aws.servicecatalog.model.primitives.{
  StackSetMaxConcurrencyCount,
  AccountId,
  StackSetFailureToleranceCount,
  Region,
  StackSetFailureTolerancePercentage,
  StackSetMaxConcurrencyPercentage
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class UpdateProvisioningPreferences(
    stackSetAccounts: Optional[Iterable[AccountId]] = Optional.Absent,
    stackSetRegions: Optional[Iterable[Region]] = Optional.Absent,
    stackSetFailureToleranceCount: Optional[StackSetFailureToleranceCount] =
      Optional.Absent,
    stackSetFailureTolerancePercentage: Optional[
      StackSetFailureTolerancePercentage
    ] = Optional.Absent,
    stackSetMaxConcurrencyCount: Optional[StackSetMaxConcurrencyCount] =
      Optional.Absent,
    stackSetMaxConcurrencyPercentage: Optional[
      StackSetMaxConcurrencyPercentage
    ] = Optional.Absent,
    stackSetOperationType: Optional[
      zio.aws.servicecatalog.model.StackSetOperationType
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences = {
    import UpdateProvisioningPreferences.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
      .builder()
      .optionallyWith(
        stackSetAccounts.map(value =>
          value.map { item =>
            AccountId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.stackSetAccounts)
      .optionallyWith(
        stackSetRegions.map(value =>
          value.map { item =>
            Region.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.stackSetRegions)
      .optionallyWith(
        stackSetFailureToleranceCount.map(value =>
          StackSetFailureToleranceCount.unwrap(value): Integer
        )
      )(_.stackSetFailureToleranceCount)
      .optionallyWith(
        stackSetFailureTolerancePercentage.map(value =>
          StackSetFailureTolerancePercentage.unwrap(value): Integer
        )
      )(_.stackSetFailureTolerancePercentage)
      .optionallyWith(
        stackSetMaxConcurrencyCount.map(value =>
          StackSetMaxConcurrencyCount.unwrap(value): Integer
        )
      )(_.stackSetMaxConcurrencyCount)
      .optionallyWith(
        stackSetMaxConcurrencyPercentage.map(value =>
          StackSetMaxConcurrencyPercentage.unwrap(value): Integer
        )
      )(_.stackSetMaxConcurrencyPercentage)
      .optionallyWith(stackSetOperationType.map(value => value.unwrap))(
        _.stackSetOperationType
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.UpdateProvisioningPreferences.ReadOnly =
    zio.aws.servicecatalog.model.UpdateProvisioningPreferences
      .wrap(buildAwsValue())
}
object UpdateProvisioningPreferences {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.UpdateProvisioningPreferences =
      zio.aws.servicecatalog.model.UpdateProvisioningPreferences(
        stackSetAccounts.map(value => value),
        stackSetRegions.map(value => value),
        stackSetFailureToleranceCount.map(value => value),
        stackSetFailureTolerancePercentage.map(value => value),
        stackSetMaxConcurrencyCount.map(value => value),
        stackSetMaxConcurrencyPercentage.map(value => value),
        stackSetOperationType.map(value => value)
      )
    def stackSetAccounts: Optional[List[AccountId]]
    def stackSetRegions: Optional[List[Region]]
    def stackSetFailureToleranceCount: Optional[StackSetFailureToleranceCount]
    def stackSetFailureTolerancePercentage
        : Optional[StackSetFailureTolerancePercentage]
    def stackSetMaxConcurrencyCount: Optional[StackSetMaxConcurrencyCount]
    def stackSetMaxConcurrencyPercentage
        : Optional[StackSetMaxConcurrencyPercentage]
    def stackSetOperationType
        : Optional[zio.aws.servicecatalog.model.StackSetOperationType]
    def getStackSetAccounts: ZIO[Any, AwsError, List[AccountId]] =
      AwsError.unwrapOptionField("stackSetAccounts", stackSetAccounts)
    def getStackSetRegions: ZIO[Any, AwsError, List[Region]] =
      AwsError.unwrapOptionField("stackSetRegions", stackSetRegions)
    def getStackSetFailureToleranceCount
        : ZIO[Any, AwsError, StackSetFailureToleranceCount] =
      AwsError.unwrapOptionField(
        "stackSetFailureToleranceCount",
        stackSetFailureToleranceCount
      )
    def getStackSetFailureTolerancePercentage
        : ZIO[Any, AwsError, StackSetFailureTolerancePercentage] =
      AwsError.unwrapOptionField(
        "stackSetFailureTolerancePercentage",
        stackSetFailureTolerancePercentage
      )
    def getStackSetMaxConcurrencyCount
        : ZIO[Any, AwsError, StackSetMaxConcurrencyCount] =
      AwsError.unwrapOptionField(
        "stackSetMaxConcurrencyCount",
        stackSetMaxConcurrencyCount
      )
    def getStackSetMaxConcurrencyPercentage
        : ZIO[Any, AwsError, StackSetMaxConcurrencyPercentage] =
      AwsError.unwrapOptionField(
        "stackSetMaxConcurrencyPercentage",
        stackSetMaxConcurrencyPercentage
      )
    def getStackSetOperationType: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.StackSetOperationType
    ] =
      AwsError.unwrapOptionField("stackSetOperationType", stackSetOperationType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
  ) extends zio.aws.servicecatalog.model.UpdateProvisioningPreferences.ReadOnly {
    override val stackSetAccounts: Optional[List[AccountId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stackSetAccounts())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.servicecatalog.model.primitives.AccountId(item)
          }.toList
        )
    override val stackSetRegions: Optional[List[Region]] = zio.aws.core.internal
      .optionalFromNullable(impl.stackSetRegions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.servicecatalog.model.primitives.Region(item)
        }.toList
      )
    override val stackSetFailureToleranceCount
        : Optional[StackSetFailureToleranceCount] = zio.aws.core.internal
      .optionalFromNullable(impl.stackSetFailureToleranceCount())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetFailureToleranceCount(value)
      )
    override val stackSetFailureTolerancePercentage
        : Optional[StackSetFailureTolerancePercentage] = zio.aws.core.internal
      .optionalFromNullable(impl.stackSetFailureTolerancePercentage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetFailureTolerancePercentage(value)
      )
    override val stackSetMaxConcurrencyCount
        : Optional[StackSetMaxConcurrencyCount] = zio.aws.core.internal
      .optionalFromNullable(impl.stackSetMaxConcurrencyCount())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetMaxConcurrencyCount(value)
      )
    override val stackSetMaxConcurrencyPercentage
        : Optional[StackSetMaxConcurrencyPercentage] = zio.aws.core.internal
      .optionalFromNullable(impl.stackSetMaxConcurrencyPercentage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives
          .StackSetMaxConcurrencyPercentage(value)
      )
    override val stackSetOperationType
        : Optional[zio.aws.servicecatalog.model.StackSetOperationType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stackSetOperationType())
        .map(value =>
          zio.aws.servicecatalog.model.StackSetOperationType.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateProvisioningPreferences
  ): zio.aws.servicecatalog.model.UpdateProvisioningPreferences.ReadOnly =
    new Wrapper(impl)
}
